### Slowly Changing Dimensions - Type 2

Simplifies and unifies the logic for performing SCD type 2 data comparisons.

**Stack:**
* 'Python 3.9.10+'


**Quick Start:**
```commandline
pip install scd_type2
```
